step

package
v1.4.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 2, 2024 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package step implements different steps that could be used in a strategy

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Interface

type Interface interface {
	Check(ticker *models.Ticker) (bool, error)
}

Interface is the interface for every Step that we want to execute in the strategy

Returns: bool: Continue to the next step? error: error ocurred running the step

Jump to