strategy

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 9, 2024 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package strategy package is a versatile toolkit designed for organizing and managing trading strategies within a trading bot framework. It offers a structured approach for encapsulating various trading algorithms, enabling easy integration and swapping of strategies within the bot.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Interface

type Interface interface {
	Run(ticker models.Ticker, steps []step.Interface) error
}

Interface is the contract that must be follow to create a new strategy for the bot

Jump to